@@ -43,37 +43,6 @@ pub(super) fn cmpinclude<P: AsRef<Path>>(localpath: P, subpath: &str) -> Option<
     }
 }
 
-#[test]
-fn tst_cmp_included_cmake() {
-    use std::fs::File;
-
-    use tempfile::tempdir;
-    let dir = tempdir().unwrap();
-    let top_cmake = dir.path().join("CMakeLists.txt");
-    File::create_new(&top_cmake).unwrap();
-    let include_cmake = dir.path().join("abcd_test.cmake");
-    File::create_new(&include_cmake).unwrap();
-
-    let locations = cmpinclude(&top_cmake, "abcd_test.cmake").unwrap();
-
-    assert_eq!(
-        locations,
-        vec![Location {
-            range: lsp_types::Range {
-                start: lsp_types::Position {
-                    line: 0,
-                    character: 0,
-                },
-                end: lsp_types::Position {
-                    line: 0,
-                    character: 0,
-                },
-            },
-            uri: Uri::from_file_path(include_cmake).unwrap(),
-        }]
-    );
-}
-
 type CacheData = HashMap<PathBuf, Vec<CacheDataUnit>>;
 
 static PACKAGE_COMPLETE_CACHE: LazyLock<Arc<Mutex<CacheData>>> =
@@ -118,67 +87,6 @@ pub fn scanner_include_defs(
     result_data
 }
 
-#[test]
-fn scanner_include_defs_tst() {
-    use std::fs::File;
-    use std::io::Write;
-
-    use tempfile::tempdir;
-    let dir = tempdir().unwrap();
-    let top_cmake = dir.path().join("CMakeLists.txt");
-
-    let mut cmake_file = File::create_new(&top_cmake).unwrap();
-    let top_cmake_context = r#"
-include(abcd_test.cmake)
-"#;
-    writeln!(cmake_file, "{}", top_cmake_context).unwrap();
-    let include_cmake_path = dir.path().join("abcd_test.cmake");
-    let mut include_cmake = File::create_new(&include_cmake_path).unwrap();
-    let include_cmake_context = r#"
-set(ABCD "abcd")
-include(efg_test.cmake)
-"#;
-    writeln!(include_cmake, "{}", include_cmake_context).unwrap();
-
-    // NOTE: this is used to test if the include cache append will work
-    let include_cmake_path_2 = dir.path().join("efg_test.cmake");
-    File::create(&include_cmake_path_2).unwrap();
-
-    let mut include_files = vec![];
-    let data = scanner_include_defs(
-        &include_cmake_path,
-        PositionType::VarOrFun,
-        &mut include_files,
-        &mut vec![],
-        false,
-        false,
-    )
-    .unwrap();
-
-    assert_eq!(
-        data,
-        vec![CacheDataUnit {
-            key: "ABCD".to_string(),
-            location: Location {
-                uri: Uri::from_file_path(&include_cmake_path).unwrap(),
-                range: lsp_types::Range {
-                    start: lsp_types::Position {
-                        line: 1,
-                        character: 4
-                    },
-                    end: lsp_types::Position {
-                        line: 1,
-                        character: 8
-                    }
-                }
-            },
-            document_info: format!("defined variable\nfrom: {}", include_cmake_path.display()),
-            is_function: false
-        }]
-    );
-    assert_eq!(include_files, vec![include_cmake_path_2]);
-}
-
 pub fn scanner_package_defs(
     path: &PathBuf,
     postype: PositionType,
@@ -211,3 +119,98 @@ pub fn scanner_package_defs(
     }
     result_data
 }
+
+#[cfg(test)]
+mod tests {
+    use std::fs::File;
+    use std::io::Write;
+
+    use tempfile::tempdir;
+
+    use super::*;
+
+    #[test]
+    fn test_cmp_included_cmake() {
+        let dir = tempdir().unwrap();
+        let top_cmake = dir.path().join("CMakeLists.txt");
+        File::create_new(&top_cmake).unwrap();
+        let include_cmake = dir.path().join("abcd_test.cmake");
+        File::create_new(&include_cmake).unwrap();
+
+        let locations = cmpinclude(&top_cmake, "abcd_test.cmake").unwrap();
+
+        assert_eq!(
+            locations,
+            vec![Location {
+                range: lsp_types::Range {
+                    start: lsp_types::Position {
+                        line: 0,
+                        character: 0,
+                    },
+                    end: lsp_types::Position {
+                        line: 0,
+                        character: 0,
+                    },
+                },
+                uri: Uri::from_file_path(include_cmake).unwrap(),
+            }]
+        );
+    }
+
+    #[test]
+    fn scanner_include_defs_test() {
+        let dir = tempdir().unwrap();
+        let top_cmake = dir.path().join("CMakeLists.txt");
+
+        let mut cmake_file = File::create_new(&top_cmake).unwrap();
+        let top_cmake_context = r#"
+include(abcd_test.cmake)
+"#;
+        writeln!(cmake_file, "{}", top_cmake_context).unwrap();
+        let include_cmake_path = dir.path().join("abcd_test.cmake");
+        let mut include_cmake = File::create_new(&include_cmake_path).unwrap();
+        let include_cmake_context = r#"
+set(ABCD "abcd")
+include(efg_test.cmake)
+"#;
+        writeln!(include_cmake, "{}", include_cmake_context).unwrap();
+
+        // NOTE: this is used to test if the include cache append will work
+        let include_cmake_path_2 = dir.path().join("efg_test.cmake");
+        File::create(&include_cmake_path_2).unwrap();
+
+        let mut include_files = vec![];
+        let data = scanner_include_defs(
+            &include_cmake_path,
+            PositionType::VarOrFun,
+            &mut include_files,
+            &mut vec![],
+            false,
+            false,
+        )
+        .unwrap();
+
+        assert_eq!(
+            data,
+            vec![CacheDataUnit {
+                key: "ABCD".to_string(),
+                location: Location {
+                    uri: Uri::from_file_path(&include_cmake_path).unwrap(),
+                    range: lsp_types::Range {
+                        start: lsp_types::Position {
+                            line: 1,
+                            character: 4
+                        },
+                        end: lsp_types::Position {
+                            line: 1,
+                            character: 8
+                        }
+                    }
+                },
+                document_info: format!("defined variable\nfrom: {}", include_cmake_path.display()),
+                is_function: false
+            }]
+        );
+        assert_eq!(include_files, vec![include_cmake_path_2]);
+    }
+}
