@@ -1,6 +1,7 @@
 use std::collections::HashMap;
 use std::path::Path;
 
+use dashmap::DashMap;
 use tower_lsp::lsp_types::{Location, Position, TextEdit, Uri, WorkspaceEdit};
 
 use crate::jump;
@@ -11,9 +12,10 @@ pub async fn rename<P: AsRef<Path>>(
     originuri: P,
     client: &tower_lsp::Client,
     source: &str,
+    documents: &DashMap<Uri, String>,
 ) -> Option<WorkspaceEdit> {
     let mut changes: HashMap<Uri, Vec<TextEdit>> = HashMap::new();
-    let defs = jump::godef(location, source, originuri, client, false, true).await?;
+    let defs = jump::godef(location, source, originuri, client, false, true, documents).await?;
 
     for Location { uri, range } in defs {
         let edits = changes.entry(uri).or_default();
